@@ -56,17 +56,18 @@ public final class FrequencyCounts
 	private final double minValue;
 	private final boolean noTf;
 	private final double offset;
+	private final double range;
 	private final int removeUnique;
 	private final BloomFilter<Long> validMers;
 	
-	public static final double REPEAT_SCALE = 3.0;
-	
-	public FrequencyCounts(BufferedReader bf, double filterCutoff, double offset, int removeUnique, boolean noTf, int numThreads) throws IOException
+	public FrequencyCounts(BufferedReader bf, double filterCutoff, double offset, int removeUnique, boolean noTf, int numThreads, double range, boolean doReverseCompliment) throws IOException
 	{
 		//removeUnique = 0: do nothing extra to k-mers not specified in the file
 		//removeUnique = 1: remove k-mers not specified in the file from the sketch
 		//removeUnique = 2: supress k-mers not specified in the file the same as max supression
 		
+		this.range = range;
+		
 		if (removeUnique<0 || removeUnique>2)
 			throw new MhapRuntimeException("Unknown removeUnique option "+removeUnique+".");
 		
@@ -78,7 +79,7 @@ public final class FrequencyCounts
 		this.noTf = noTf;
 		
 		// generate hashset
-		Long2DoubleOpenHashMap validMap = new Long2DoubleOpenHashMap();
+		Long2DoubleOpenHashMap validMap;
 		BloomFilter<Long> validMers;
 
 		//the max value observed in the list
@@ -88,29 +89,52 @@ public final class FrequencyCounts
 		String line = bf.readLine();
 		try
 		{
-			long size;
+			long sizeBloom;
+			long sizeRepeat;
 			if (line==null)
 			{
 				System.err.println("Warning, k-mer filter file is empty. Assuming zero entries.");
-				size = 1L;
+				sizeBloom = sizeRepeat = 1L;
 			}
 			else
 			{
-				size = Long.parseLong(line);
+				// we assume the line has two entries, the first is the size of the bloom filter, the second is the size of the filter set
+				String[] splitLine = line.trim().split("\\s+");
+				sizeBloom = Long.parseLong(splitLine[0]);
+				sizeRepeat = Long.parseLong(splitLine[1]);
+				System.err.println("Read in values for repeat " + sizeRepeat + " and " + sizeBloom);
 			
-				if (size<0L)
+				if (sizeBloom<0L || sizeRepeat <0L)
 					throw new MhapRuntimeException("K-mer filter file size line must have positive long value.");
 				else
-				if (size==0L)
+				if (sizeBloom==0L)
 				{
 					System.err.println("Warning, k-mer filter file has zero elements.");
-					size = 1L;
+					sizeBloom = 1L;
 				}
 			}
 			
+			System.err.println("Initializing");
+			Long2DoubleOpenHashMap tempMap = null;
+			for (long i = sizeRepeat; i > 0; i /= 2) {
+				try {	
+					System.err.print("Trying size " + i);
+					tempMap = new Long2DoubleOpenHashMap((int)(i));
+					System.err.println(" and it was successfull");
+					break;
+				} catch (IllegalArgumentException e) {
+					System.err.println(" and it was too big, trying smaller");
+				}
+			}
+			if (tempMap == null)
+				validMap = new Long2DoubleOpenHashMap();
+			else
+				validMap = tempMap;
+			System.err.println("Initialized");
+
 			//if no nothing, no need to store the while list
 			if (removeUnique>0)
-				validMers = BloomFilter.create((value, sink) -> sink.putLong(value), size, 1.0e-5);
+				validMers = BloomFilter.create((value, sink) -> sink.putLong(value), sizeBloom, 1.0e-5);
 			else
 				validMers = null;
 		}
@@ -142,7 +166,7 @@ public final class FrequencyCounts
 						this.kmerSizes.add(str[0].length());
 					}					
 					
-					long[] hash = HashUtils.computeSequenceHashesLong(str[0], str[0].length(), 0);
+					long[] hash = HashUtils.computeSequenceHashesLong(str[0], str[0].length(), 0, doReverseCompliment);
 					
 					if (str.length >= 2)
 					{
@@ -265,7 +289,7 @@ public final class FrequencyCounts
 	
 	public double scaledIdf(long hash)
 	{
-		return scaledIdf(hash, REPEAT_SCALE);
+		return scaledIdf(hash, this.range);
 	}
 	
 	public double scaledIdf(long hash, double maxValue)
